==> qmmp_0.6.3.orig.tar.gz: qmmp-0.6.3/src/plugins/Visual/projectm/translations/projectm_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>ProjectMPlugin</name>
    <message>
        <location filename="../projectmplugin.cpp" line="40"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
</context>
<context>
    <name>ProjectMWidget</name>
    <message>
        <location filename="../projectmwidget.cpp" line="134"/>
        <source>&amp;Help</source>
        <translation>&amp;Hulp</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="134"/>
        <source>F1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="135"/>
        <source>&amp;Show Song Title</source>
        <translation>&amp;Weergeef Titel van Nummer</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="135"/>
        <source>F2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="136"/>
        <source>&amp;Show Preset Name</source>
        <translation>&amp;Weergeef Naam van Voorinstellingen</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="136"/>
        <source>F3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="138"/>
        <source>&amp;Next Preset</source>
        <translation>&amp;Volgende Instelling</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="138"/>
        <source>N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="139"/>
        <source>&amp;Previous Preset</source>
        <translation>&amp;Vorige Instelling</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="139"/>
        <source>P</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="140"/>
        <source>&amp;Random Preset</source>
        <translation>&amp;Willekeurige Instelling</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="140"/>
        <source>R</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="141"/>
        <source>&amp;Lock Preset</source>
        <translation>&amp;Zet Instelling Vast</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="141"/>
        <source>L</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="143"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Volledig scherm</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="143"/>
        <source>F</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>VisualProjectMFactory</name>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="29"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="49"/>
        <source>About ProjectM Visual Plugin</source>
        <translation>Over de ProjectM Visuele Module</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="50"/>
        <source>Qmmp ProjectM Visual Plugin</source>
        <translation>ProjectM Visuele Module voor Qmmp</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="51"/>
        <source>This plugin adds projectM visualization</source>
        <translation>Deze plugin voegt projectM visualisatie toe</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="53"/>
        <source>Based on llibrojectM-qt library</source>
        <translation>Gebasseerd op de libprojectM-qt bibliotheek</translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/Visual/projectm/translations/projectm_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>ProjectMPlugin</name>
    <message>
        <location filename="../projectmplugin.cpp" line="41"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
</context>
<context>
    <name>ProjectMWidget</name>
    <message>
        <location filename="../projectmwidget.cpp" line="164"/>
        <source>&amp;Help</source>
        <translation>&amp;Hulp</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="164"/>
        <source>F1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="165"/>
        <source>&amp;Show Song Title</source>
        <translation>&amp;Weergeef Titel van Nummer</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="165"/>
        <source>F2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="166"/>
        <source>&amp;Show Preset Name</source>
        <translation>&amp;Weergeef Naam van Voorinstellingen</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="166"/>
        <source>F3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="167"/>
        <source>&amp;Show Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="167"/>
        <source>M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="169"/>
        <source>&amp;Next Preset</source>
        <translation>&amp;Volgende Instelling</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="169"/>
        <source>N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="170"/>
        <source>&amp;Previous Preset</source>
        <translation>&amp;Vorige Instelling</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="170"/>
        <source>P</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="171"/>
        <source>&amp;Random Preset</source>
        <translation>&amp;Willekeurige Instelling</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="171"/>
        <source>R</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="172"/>
        <source>&amp;Lock Preset</source>
        <translation>&amp;Zet Instelling Vast</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="172"/>
        <source>L</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="174"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Volledig scherm</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="174"/>
        <source>F</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>VisualProjectMFactory</name>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="31"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="51"/>
        <source>About ProjectM Visual Plugin</source>
        <translation>Over de ProjectM Visuele Module</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="52"/>
        <source>Qmmp ProjectM Visual Plugin</source>
        <translation>ProjectM Visuele Module voor Qmmp</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="53"/>
        <source>This plugin adds projectM visualization</source>
        <translation>Deze plugin voegt projectM visualisatie toe</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="55"/>
        <source>Based on libprojectM-qt library</source>
        <translation>Gebasseerd op de libprojectM-qt bibliotheek</translation>
    </message>
</context>
</TS>
